#include <osgTerrain/Version>

const char* osgTerrainGetVersion()
{
    return "1.1";
}


const char* osgTerrainGetLibraryName()
{
    return "OpenSceneGraph Terrain Library";
}
